import { EventEmitter, Type } from '@angular/core';
import { Routes } from '@angular/router';
import { Subject } from 'rxjs';
import { eLayoutType } from '../enums/common';
import { Environment } from './environment';
export declare namespace ABP {
    interface Root {
        environment: Partial<Environment>;
        registerLocaleFn: (locale: string) => Promise<any>;
        skipGetAppConfiguration?: boolean;
        skipInitAuthService?: boolean;
        sendNullsAsQueryParam?: boolean;
        tenantKey?: string;
        localizations?: Localization[];
        othersGroup?: string;
        dynamicLayouts?: Map<string, string>;
        disableProjectNameInTitle?: boolean;
    }
    interface Child {
        localizations?: Localization[];
    }
    interface Localization {
        culture: string;
        resources: LocalizationResource[];
    }
    interface LocalizationResource {
        resourceName: string;
        texts: Record<string, string>;
    }
    interface HasPolicy {
        requiredPolicy?: string;
    }
    interface Test extends Partial<Root> {
        baseHref?: string;
        listQueryDebounceTime?: number;
        routes?: Routes;
    }
    type PagedResponse<T> = {
        totalCount: number;
    } & PagedItemsResponse<T>;
    interface PagedItemsResponse<T> {
        items: T[];
    }
    interface PageQueryParams {
        filter?: string;
        sorting?: string;
        skipCount?: number;
        maxResultCount?: number;
    }
    interface Lookup {
        id: string;
        displayName: string;
    }
    interface Nav {
        name: string;
        parentName?: string;
        requiredPolicy?: string;
        order?: number;
        invisible?: boolean;
    }
    interface Route extends Nav {
        path?: string;
        layout?: eLayoutType;
        iconClass?: string;
        group?: string;
        breadcrumbText?: string;
    }
    interface Tab extends Nav {
        component: Type<any>;
    }
    interface BasicItem {
        id: string;
        name: string;
    }
    interface Option<T> {
        key: Extract<keyof T, string>;
        value: T[Extract<keyof T, string>];
    }
    interface Dictionary<T = any> {
        [key: string]: T;
    }
    type ExtractFromOutput<T extends EventEmitter<any> | Subject<any>> = T extends EventEmitter<infer X> ? X : T extends Subject<infer Y> ? Y : never;
}
