import { Injector, OnDestroy } from '@angular/core';
import { Observable } from 'rxjs';
import { ABP } from '../models/common';
import { TreeNode, RouteGroup } from '../utils/tree-utils';
import * as i0 from "@angular/core";
export declare abstract class AbstractTreeService<T extends {
    [key: string | number | symbol]: any;
}> {
    abstract id: string;
    abstract parentId: string;
    abstract hide: (item: T) => boolean;
    abstract sort: (a: T, b: T) => number;
    private _flat$;
    private _tree$;
    private _visible$;
    protected othersGroup: string;
    protected shouldSingularizeRoutes: boolean;
    get flat(): T[];
    get flat$(): Observable<T[]>;
    get tree(): TreeNode<T>[];
    get tree$(): Observable<TreeNode<T>[]>;
    get visible(): TreeNode<T>[];
    get visible$(): Observable<TreeNode<T>[]>;
    private filterWith;
    private findItemsToRemove;
    private publish;
    protected createTree(items: T[]): TreeNode<T>[];
    protected createGroupedTree(list: TreeNode<T>[]): RouteGroup<T>[] | undefined;
    add(items: T[]): T[];
    find(predicate: (item: TreeNode<T>) => boolean, tree?: TreeNode<T>[]): TreeNode<T> | null;
    patch(identifier: string, props: Partial<T>): T[] | false;
    refresh(): T[];
    remove(identifiers: string[]): T[];
    removeByParam(params: Partial<T>): T[] | null;
    search(params: Partial<T>, tree?: TreeNode<T>[]): TreeNode<T> | null;
    setSingularizeStatus(singularize?: boolean): void;
}
export declare abstract class AbstractNavTreeService<T extends ABP.Nav> extends AbstractTreeService<T> implements OnDestroy {
    protected injector: Injector;
    private subscription;
    private permissionService;
    private compareFunc;
    readonly id = "name";
    readonly parentId = "parentName";
    readonly hide: (item: T) => boolean;
    readonly sort: (a: T, b: T) => any;
    constructor(injector: Injector);
    protected isGranted({ requiredPolicy }: T): boolean;
    hasChildren(identifier: string): boolean;
    hasInvisibleChild(identifier: string): boolean;
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<AbstractNavTreeService<any>, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<AbstractNavTreeService<any>>;
}
export declare class RoutesService extends AbstractNavTreeService<ABP.Route> {
    private hasPathOrChild;
    get groupedVisible(): RouteGroup<ABP.Route>[] | undefined;
    get groupedVisible$(): Observable<RouteGroup<ABP.Route>[] | undefined>;
    static ɵfac: i0.ɵɵFactoryDeclaration<RoutesService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<RoutesService>;
}
