import { ConfigStateService } from './config-state.service';
import * as i0 from "@angular/core";
export declare class TimezoneService {
    protected readonly configState: ConfigStateService;
    protected readonly document: Document;
    private readonly cookieKey;
    private timeZoneNameFromSettings;
    isUtcClockEnabled: boolean | undefined;
    constructor();
    /**
     * Returns the effective timezone to be used across the application.
     *
     * This value is determined based on the clock kind setting in the configuration:
     * - If clock kind is not equal to Utc, the browser's local timezone is returned.
     * - If clock kind is equal to Utc, the configured timezone (`timeZoneNameFromSettings`) is returned if available;
     *   otherwise, the browser's timezone is used as a fallback.
     *
     * @returns The IANA timezone name (e.g., 'Europe/Istanbul', 'America/New_York').
     */
    get timezone(): string;
    /**
     * Retrieves the browser's local timezone based on the user's system settings.
     *
     * @returns The IANA timezone name (e.g., 'Europe/Istanbul', 'America/New_York').
     */
    getBrowserTimezone(): string;
    /**
     * Sets the application's timezone in a cookie to persist the user's selected timezone.
     *
     * This method sets the cookie only if the clock kind setting is set to UTC.
     * The cookie is stored using the key defined by `this.cookieKey` and applied to the root path (`/`).
     *
     * @param timezone - The IANA timezone name to be stored (e.g., 'Europe/Istanbul').
     */
    setTimezone(timezone: string): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TimezoneService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<TimezoneService>;
}
