import { ContentSecurityStrategy } from './content-security.strategy';
import { DomStrategy } from './dom.strategy';
export type ElementOptions<T extends HTMLScriptElement | HTMLStyleElement = any> = Partial<{
    [key in keyof T]: T[key];
}>;
export declare abstract class ContentStrategy<T extends HTMLScriptElement | HTMLStyleElement = any> {
    content: string;
    protected domStrategy: DomStrategy;
    protected contentSecurityStrategy: ContentSecurityStrategy;
    protected options: ElementOptions<T>;
    constructor(content: string, domStrategy?: DomStrategy, contentSecurityStrategy?: ContentSecurityStrategy, options?: ElementOptions<T>);
    abstract createElement(): T;
    insertElement(): T;
}
export declare class StyleContentStrategy extends ContentStrategy<HTMLStyleElement> {
    createElement(): HTMLStyleElement;
}
export declare class ScriptContentStrategy extends ContentStrategy<HTMLScriptElement> {
    createElement(): HTMLScriptElement;
}
export declare const CONTENT_STRATEGY: {
    AppendScriptToBody(content: string, options?: ElementOptions<HTMLScriptElement>): ScriptContentStrategy;
    AppendScriptToHead(content: string, options?: ElementOptions<HTMLScriptElement>): ScriptContentStrategy;
    AppendStyleToHead(content: string, options?: ElementOptions<HTMLStyleElement>): StyleContentStrategy;
    PrependStyleToHead(content: string, options?: ElementOptions<HTMLStyleElement>): StyleContentStrategy;
};
